pub trait SimilaritySessionGraphReceiver:
Send
+ Sync
+ 'static {
// Required method
fn on_graph_changed(&self);
}Expand description
Receives notifications after nodes or edges are added to or removed from a session graph.
pub trait SimilaritySessionGraphReceiver:
Send
+ Sync
+ 'static {
// Required method
fn on_graph_changed(&self);
}Receives notifications after nodes or edges are added to or removed from a session graph.